pub struct Section {
pub block_count: u16,
pub fluid_count: u16,
pub states: PalettedContainer<BlockState>,
pub biomes: PalettedContainer<Biome>,
}Expand description
A section of a chunk, i.e. a 161616 block area.
Fields
block_count: u16The number of non-empty blocks in the section, which is initialized based on a value sent to us by the server.
This may be updated every time Self::get_and_set_block_state is
called.
fluid_count: u16Similar to Self::block_count, but for fluids.
Unlike Self::block_count, this is currently not updated by Azalea.
states: PalettedContainer<BlockState>biomes: PalettedContainer<Biome>Implementations
Sourceimpl Section
impl Section
pub fn get_block_state(&self, pos: ChunkSectionBlockPos) -> BlockState
pub fn get_and_set_block_state( &mut self, pos: ChunkSectionBlockPos, state: BlockState, ) -> BlockState
pub fn get_biome(&self, pos: ChunkSectionBiomePos) -> Biome
pub fn set_biome(&mut self, pos: ChunkSectionBiomePos, biome: Biome)
pub fn get_and_set_biome( &mut self, pos: ChunkSectionBiomePos, biome: Biome, ) -> Biome