pub struct PartialEntityInfos {
pub owner_entity: Option<Entity>,
pub updates_received: IntMap<MinecraftEntityId, u32>,
}Expand description
Keep track of certain metadatas that are only relevant for this partial world.
Fields
owner_entity: Option<Entity>The entity ID of the player that owns this partial world.
This will make RelativeEntityUpdate pretend this entity doesn’t exist
so it doesn’t get modified from outside sources.
updates_received: IntMap<MinecraftEntityId, u32>A counter for each entity that tracks how many updates we’ve observed for it.
This is used for shared worlds (i.e. swarms), to make sure we don’t update entities twice on accident.
Implementations