PartialWorld

Struct PartialWorld 

pub struct PartialWorld {
    pub chunks: PartialChunkStorage,
    pub entity_infos: PartialEntityInfos,
}
A reference to a slice of the world, as seen by an individual client.

A PartialWorld will typically be owned by a client, and it holds strong references to chunks and entities in a Worlds.

In other words, this type holds the chunks and entities that are within render distance for a client. The same chunk/entity may be referenced by more than one PartialWorld.

Fields

chunks: PartialChunkStorageentity_infos: PartialEntityInfos

Some metadata about entities, like what entities are in certain chunks. This does not contain the entity data itself, that’s in the ECS.

Implementations

Source

impl PartialWorld

pub fn new(chunk_radius: u32, owner_entity: Option<Entity>) -> Self

pub fn reset(&mut self)

Clears the internal references to chunks in the PartialWorld and resets the view center.